@@ -23,7 +23,7 @@ from xml.sax.saxutils import escape, unescape
 
 import editabletuple
 
-__version__ = '0.9.3'
+__version__ = '0.9.4'
 
 
 class Tdb:
@@ -400,6 +400,10 @@ class Table:
         self.records.append(record)
 
 
+    def __iter__(self):
+        return iter(self.records)
+
+
     def __repr__(self):
         meta = '\n  '.join((str(m) for m in self.fields_meta))
         return f'{self.__class__.__name__}({self.name!r})\n  ' + meta
